@@ -12,7 +12,7 @@ done
 $CMD \
 --release \
 --siteurl="http://www.ufoot.org" \
---htprefix="/uwikicms" \
+--htprefix="" \
 --dbhost=$UFOOT_ORG_DBHOST \
 --dbname=$UFOOT_ORG_DBNAME \
 --dbuser=$UFOOT_ORG_DBUSER \
