@@ -22,6 +22,7 @@ define(UWC_CONTEXTUTILS_UWIKICMS_PATH,"/\\/_uwikicms/");
 define(UWC_CONTEXTUTILS_IMAGE_PAGE_PATH,"/img\\-(\\d+)$/");
 define(UWC_CONTEXTUTILS_IMAGE_PREVIEW_PATH,"/img\\-(\\d+)\\-preview\\.jpeg$/");
 define(UWC_CONTEXTUTILS_IMAGE_FULL_PATH,"/img\\-(\\d+)\\.jpeg$/");
+define(UWC_CONTEXTUTILS_GALLERY_PATH,"/gallery\\.xul$/");
 
 function uwc_contextutils_is_uwikicms_path($path) {
   return preg_match(UWC_CONTEXTUTILS_UWIKICMS_PATH,$path);
@@ -39,6 +40,10 @@ function uwc_contextutils_is_image_full_path($path) {
   return preg_match(UWC_CONTEXTUTILS_IMAGE_FULL_PATH,$path);
 }
 
+function uwc_contextutils_is_gallery_path($path) {
+  return preg_match(UWC_CONTEXTUTILS_GALLERY_PATH,$path);
+}
+
 function uwc_contextutils_fix_path($path) {
   // Make sure we've a heading /
   $path="/".$path;
