@@ -60,6 +60,10 @@ function uwc_format_text_to_html($str) {
   return uwc_format_htmlfriendly(htmlentities($str));
 }
 
+function uwc_format_text_to_xul($str) {
+  return htmlspecialchars(html_entity_decode(uwc_format_text_to_html($str)));
+}
+
 function uwc_format_text_to_html_attribute($str) {
   /*
    * Usefull to format stuff for html attributes like
@@ -82,6 +86,18 @@ function uwc_format_phpwiki_to_html($str) {
   return uwc_format_htmlfriendly($html);
 }
 
+function uwc_format_fix_content_text($str) {
+  /*
+   * Fixes the text fill when inserting/updating content.
+   * The idea is that we filter the typed text, mostly for
+   * inlined images, which we want to be separated from the rest.
+   */
+  $str=preg_replace("/\r/","",$str);
+  $str=preg_replace("/\n*\s*\[\s*img\s*\:\s*(\d+)\s*\]\s*\n*/","\n\n[ img:\\1 ]\n\n",$str);
+
+  return $str;
+}
+
 function uwc_format_readable_size($size) {
   if ($size<1000) {
     $readable_size=sprintf("%d ",$size);
@@ -129,7 +145,7 @@ function uwc_format_html_for_img_link_preview($url_page,$url_preview,$w,$h,$alt,
   //$longdesc=uwc_format_text_to_html(uwc_format_cut_text($longdesc,UWC_FORMAT_LONGDESC_CUT));
   $longdesc=uwc_format_text_to_html($longdesc);
   
-  $html="<div class=\"image $style\"><div><a href=\"$url_page\"><img src=\"$url_preview\" width=$w height=$h alt=\"$alt\" class=\"msiehackimage\" /></a></div><div>$longdesc</div></div>\n";
+  $html="<div class=\"image $style\"><div><a href=\"$url_page\"><img src=\"$url_preview\" width=\"$w\" height=\"$h\" alt=\"$alt\" class=\"msiehackimage\" /></a></div><div>$longdesc</div></div>\n";
   
   return $html;
 }
@@ -139,7 +155,7 @@ function uwc_format_html_for_img_link_full($url_page,$url_preview,$w,$h,$alt,$lo
   //$longdesc=uwc_format_text_to_html(uwc_format_cut_text($longdesc,UWC_FORMAT_LONGDESC_CUT));
   $longdesc=uwc_format_text_to_html($longdesc);
   
-  $html="<div class=\"image full\"><div><a href=\"$url_page\"><img src=\"$url_preview\" width=$w height=$h alt=\"$alt\" class=\"msiehackimage\" /></a></div><div>$longdesc</div></div>\n";
+  $html="<div class=\"image full\"><div><a href=\"$url_page\"><img src=\"$url_preview\" width=\"$w\" height=\"$h\" alt=\"$alt\" class=\"msiehackimage\" /></a></div><div>$longdesc</div></div>\n";
   
   return $html;
 }
