@@ -80,6 +80,7 @@ $this->messages=array
    "action_imagenew"=>"Nouvelle image",
    "action_clearcache"=>"Vider le cache",
    "action_allinone"=>"Tout sur une page",
+   "action_gallery"=>"Diaporama (Mozilla/Firefox)",
    "login_success"=>"Connect&eacute; en tant que %s.",
    "login_failed"=>"La connexion a &eacute;chou&eacute;.",
    "login_user"=>"Identifiant",
@@ -114,6 +115,9 @@ $this->messages=array
    "current_image"=>"Image actuelle",
    "allinone_status"=>"N'afficher que les documents dans cet &eacute;tat",
    "allinone_max_size"=>"Taille max des images (en pixels)",
+   "gallery_title"=>"Diaporama XUL",
+   "gallery_back"=>"Retour au site HTML",
+   "gallery_empty"=>"Aucune image dans ce diaporama",
 
    ""=>""
    );
