@@ -38,6 +38,7 @@ require("imagelist.php");
 require("external.php");
 require("phpwiki.php");
 require("horde.php");
+require("gallery.php");
 
 define(UWC_PAGE_DESCRIPTION_SIZE,80);
 
@@ -73,6 +74,8 @@ class UWC_Page {
       $this->content=new UWC_Image($this->data,$this->context->get_path(),$this->context->get_lang(),$this->auth,$this->context->get_image_id());
     } elseif (preg_match("/image/",$this->context->get_type())) {
       $this->content=new UWC_Imagebinary($this->data,$this->context->get_path(),$this->get_user_status(),$this->context->get_image_id());
+    } elseif ("gallery"==$this->context->get_type()) {
+      $this->content=new UWC_Gallery($this->data,$this->context->get_path(),$this->context->get_lang(),$this->auth);
     } else {
       $this->content=new UWC_Content($this->data,$this->context->get_path(),$this->context->get_lang(),$this->auth);
     }
@@ -580,6 +583,11 @@ class UWC_Page {
     return $this->content->get_full_h();
   }
 
+  function get_gallery_url() {
+    $path=(preg_match("/image/",$this->context->action)) ? $this->get_up_path() : $this->get_path();
+    return $this->make_url($path."/gallery.xul");
+  }
+
   function get_image_size() {
     return uwc_format_readable_size($this->content->get_size());
   }
@@ -776,6 +784,10 @@ class UWC_Page {
     return $this->lang->get_message($msg_id);
   }
 
+  function translate_xul($msg_id) {
+    return htmlspecialchars(html_entity_decode($this->translate($msg_id)));
+  }
+
   function translate1($msg_id,$par1) {
     return sprintf($this->lang->get_message($msg_id),$par1);
   }
@@ -854,7 +866,7 @@ class UWC_Page {
   }
 
   function need_action_allinone() {
-    return ($this->context->action=="view" || $this->context->action=="tree" || $this->context->action="external") && $this->auth->can_admin() && $this->viewable();
+    return ($this->context->action=="view" || $this->context->action=="tree" || $this->context->action=="external") && $this->auth->can_admin() && $this->viewable();
   }
 
   function need_action_new() {
@@ -869,6 +881,10 @@ class UWC_Page {
     return count($this->get_untranslated())>0 && $this->editable();
   }
 
+  function need_action_gallery() {
+    return (($this->context->action=="view" || $this->context->action=="external") && count($this->get_images_list())>=2) || $this->context->action=="imageview";
+  }
+
   function need_continue_url() {
     //return $this->context->get_continue_url() ? true : false;
     return true;
@@ -1025,8 +1041,12 @@ class UWC_Page {
     case "imageviewfull":
       uwc_imagebinary_view_full(& $this->data,$this->context->get_image_id());
       break;
+    case "gallery":
+      uwc_gallery_xul_header();
+      include $this->get_prefix()."/_uwikicms/template/php/".$this->context->action.".php";
+      break;
     case "new":
-      // header Location so no content...
+      // header "Location" so no content...
       break;
     default:
       /*
@@ -1070,7 +1090,6 @@ class UWC_Page {
       default:
 	include $this->get_prefix()."/_uwikicms/template/php/about.php";
       }
-      
       include $this->get_prefix()."/_uwikicms/template/php/end.php";
 
       /*
